@@ -1,6 +1,6 @@
     
 
-"link to documentation- https://github.com/suryavenom/Flexi/blob/main/README.md"
+
     #! :param means parameter
 def search_all(lists:list,value,index_range:tuple):
     """
@@ -26,6 +26,7 @@ def search_all(lists:list,value,index_range:tuple):
 
 # It's a class that takes a dictionary as an argument and stores it as an attribute
 class Flexi:
+    '''link to documentation- https://github.com/suryavenom/Flexi/blob/main/README.md'''
     def __init__(self, dictionary: dict):
         self.dictionary = dictionary
 
@@ -141,7 +142,7 @@ class Flexi:
         item = list(self.dictionary.items())[index]
         return item
 
-    def d_exchange(self, no_of_exchanges=1, return_type="no_update"):
+    def d_exchange(self, no_of_exchanges=1,return_type="no_update"):
         """
         It exchanges the keys and values of a dictionary
         :param no_of_exchanges: the number of times the dictionary is exchanged, defaults to 1 (optional)
@@ -152,18 +153,21 @@ class Flexi:
             raise Exception("type(no_of_exchanges) == int")
         if return_type not in ["no_update", "update"]:
             raise Exception("return_type should be either update or no_update")
+        
         exchanged_dictionary = self.dictionary
         if no_of_exchanges % 2 != 0:
             exchanged_dictionary = {value: key for key,
                                     value in self.dictionary.items()}
+        
         if len(self.dictionary) == len(exchanged_dictionary):
             if return_type == "update":
                 self.dictionary.clear()
                 self.dictionary.update(exchanged_dictionary)
             if return_type == "no_update":
                 return exchanged_dictionary
-        else:
+        else :
             raise Exception("the dictionary has identical values so it cannot be exchanged")
+        
 
     def d_reverse(self, no_of_times=1, return_type="no_update"):
         """
@@ -264,7 +268,7 @@ class Flexi:
             self.dictionary.clear()
             self.dictionary.update(inserted_dictionary)
 
-    def d_remove(self, index: int):
+    def d_remove(self, index_list: list):
         """
         It takes the dictionary, copies it, and then removes the key at the index
         
@@ -273,7 +277,12 @@ class Flexi:
         :return: A new dictionary with the key removed.
         """
         new_dictionary = self.dictionary.copy()
-        new_dictionary.pop(Flexi.d_key(self, index))
+        new_object = Flexi(new_dictionary)
+        index_list.sort()
+        if index_list == list(range(index_list[-1]+1)):
+            return new_object.d_split(index_list[-1]+1)[1]
+        for index in index_list:
+            new_dictionary.pop(Flexi.d_key(self, index))
         return new_dictionary
 
     def d_replace(self, index: int, key, value, return_type="no_update"):
@@ -297,7 +306,7 @@ class Flexi:
             self, index, key, value, return_type=return_type)
         if return_type == "no_update":
             replaced_dictionary = Flexi(inserted_dictionary)
-            return replaced_dictionary.d_remove(index+1)
+            return replaced_dictionary.d_remove([index+1])
         else:
             self.dictionary.pop(Flexi.d_key(self, index+1))
 
@@ -645,6 +654,13 @@ class Flexi:
         if len(items_tuple) != 0:
             for items in items_tuple:
                 if items_tuple.count(items) == 2:
-                    common_item_list.append(dict(items))
+                    if common_item_list.count(items) == 0:
+                        common_item_list.append(items)
         return tuple(common_item_list)
+from time import perf_counter
+start = perf_counter()
+x = Flexi({"a":1, "b":2,"c":3,"d":4,"e":5,"f":6,"g":7})
+print(x.d_replace(1,"j","k",return_type="update"))
+stop = perf_counter()
+print(stop - start)
 
